==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/DBCONNECTINFO_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DBCONNECTINFO_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DBCONNECTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="DBUSERNAME" type="{http://schemas.datastream.net/MP_fields}CODE128_Type"/>
 *         &lt;element name="DBPASSWORD" type="{http://schemas.datastream.net/MP_fields}CODE128_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DBCONNECTINFO_Type", propOrder = {
    "dbusername",
    "dbpassword"
})
public class DBCONNECTINFO_Type {

    @XmlElement(name = "DBUSERNAME", required = true)
    protected String dbusername;
    @XmlElement(name = "DBPASSWORD", required = true)
    protected String dbpassword;

    /**
     * Obtient la valeur de la propriété dbusername.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDBUSERNAME() {
        return dbusername;
    }

    /**
     * Définit la valeur de la propriété dbusername.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDBUSERNAME(String value) {
        this.dbusername = value;
    }

    /**
     * Obtient la valeur de la propriété dbpassword.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDBPASSWORD() {
        return dbpassword;
    }

    /**
     * Définit la valeur de la propriété dbpassword.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDBPASSWORD(String value) {
        this.dbpassword = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/DBCONNECTINFO_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DBCONNECTINFO_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DBCONNECTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="DBUSERNAME" type="{http://schemas.datastream.net/MP_fields}CODE128_Type"/>
 *         &lt;element name="DBPASSWORD" type="{http://schemas.datastream.net/MP_fields}CODE128_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DBCONNECTINFO_Type", propOrder = {
    "dbusername",
    "dbpassword"
})
public class DBCONNECTINFO_Type {

    @XmlElement(name = "DBUSERNAME", required = true)
    protected String dbusername;
    @XmlElement(name = "DBPASSWORD", required = true)
    protected String dbpassword;

    /**
     * Gets the value of the dbusername property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDBUSERNAME() {
        return dbusername;
    }

    /**
     * Sets the value of the dbusername property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDBUSERNAME(String value) {
        this.dbusername = value;
    }

    /**
     * Gets the value of the dbpassword property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDBPASSWORD() {
        return dbpassword;
    }

    /**
     * Sets the value of the dbpassword property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDBPASSWORD(String value) {
        this.dbpassword = value;
    }

}
